@@ -6,6 +6,7 @@ import tempfile
 import pkg_resources
 import urllib
 import urlparse
+import xml.sax.saxutils
 from paste.script import templates, command
 from paste.script.templates import var, NoDefault
 
@@ -17,8 +18,6 @@ class GrokProject(templates.Template):
     required_templates = []
 
     vars = [
-        var('module', 'Name of a demo Python module placed into the package',
-            default='app.py'),
         var('user', 'Name of an initial administrator user', default=NoDefault),
         var('passwd', 'Password for the initial administrator user',
             default=NoDefault),
@@ -28,18 +27,15 @@ class GrokProject(templates.Template):
 
     def check_vars(self, vars, cmd):
         vars = super(GrokProject, self).check_vars(vars, cmd)
-        module = vars['module']
-        if '.' in module:
-            if module.endswith('.py'):
-                vars['module'] = module[:-3]
-            else:
-                raise command.BadCommand('Bad module name: %s' % module)
         if vars['package'] in ('grok', 'zope'):
             print
             print "Error: The chosen project name results in an invalid " \
                   "package name: %s." % vars['package']
             print "Please choose a different project name."
             sys.exit(1)
+        for var_name in ['user', 'passwd']:
+            # Esacpe values that go in site.zcml.
+            vars[var_name] = xml.sax.saxutils.quoteattr(vars[var_name])
         vars['eggs_dir'] = os.path.expanduser(vars['eggs_dir'])
         return vars
 
@@ -55,11 +51,18 @@ def main():
                       "hierarchy).")
     parser.add_option('--newer', action="store_true", dest="newest",
                       default=False, help="Check for newer versions of packages.")
+    parser.add_option('-v', '--verbose', action="store_true", dest="verbose",
+                      default=False, help="Be verbose.")
     parser.add_option(
         '--version-info-url', dest="version_info_url", default=None,
         help="The URL to a *.cfg file containing a [versions] section.")
-    parser.add_option('-v', '--verbose', action="store_true", dest="verbose",
-                      default=False, help="Be verbose.")
+
+    # Options that override the interactive part of filling the templates.
+    for var in GrokProject.vars:
+        parser.add_option(
+            '--'+var.name.replace('_', '-'), dest=var.name,
+            help=var.description)
+
     options, args = parser.parse_args()
     if len(args) != 1:
         parser.print_usage()
@@ -83,12 +86,18 @@ def main():
     else:
         extra_args.append('newest=false')
 
+    # Process the options that override the interactive part of filling
+    # the templates.
+    for var in GrokProject.vars:
+        supplied_value = getattr(options, var.name)
+        if supplied_value is not None:
+            extra_args.append('%s=%s' % (var.name, supplied_value))
+
     version_info_url = options.version_info_url
     if not version_info_url:
         info = urllib.urlopen(VERSIONINFO_INFO_URL).read().strip()
         version_info_url = urlparse.urljoin(VERSIONINFO_INFO_URL, info)
     extra_args.append('extends=' + version_info_url)
-
     exit_code = runner.run(option_args + ['-t', 'grokproject', project]
                            + extra_args)
     # TODO exit_code
